================
 Citing HyperSpy
================

If HyperSpy has been significant to a project that leads to an academic publication,
please acknowledge that fact by citing the software. You can use the following bibtex
entry

.. code-block:: bibtex

    @misc{francisco_de_la_pena_2015_16850,
    author       = {Francisco de la Peña and
                    Pierre Burdet and
                    Michael Sarahan and
                    Magnus Nord and
                    Tomas Ostasevicius and
                    Josh Taillon and
                    Alberto Eljarrat and
                    Stefano Mazzucco and
                    Vidar Tonaas Fauske
                    Gaël Donval and
                    Luiz Fernando Zagonel and
                    Ilya Iyengar and
                    Michael Walls
                    },
    title        = {HyperSpy 0.8},
    month        = apr,
    year         = 2015,
    doi          = {10.5281/zenodo.16850},
    url          = {http://dx.doi.org/10.5281/zenodo.16850}
    }

or click on the DOI badge below for more citation formats.

.. image:: https://zenodo.org/badge/doi/10.5281/zenodo.16850.svg
   :target: http://dx.doi.org/10.5281/zenodo.16850




